# htmlx

A small python dom and html creation utility.

```python
from htmlx import html, body, h1
print(html(body(h1('Hello, World!'))))
# <html><body><h1>Hello, World!</h1></body></html>
```

### install

```bash
python3 -m pip install htmlx
```
